@@ -26,7 +26,7 @@
 #define ABOUTDATA_H
 
 #include <tdeaboutdata.h>
-#include <tdepimmacros.h>
+#include <kdemacros.h>
 
 #define AKREGATOR_VERSION "1.2.9"
 
