@@ -57,7 +57,7 @@ namespace Kleo {
   };
 
   class KDE_EXPORT CryptoBackendFactory : public TQObject {
-    Q_OBJECT
+    TQ_OBJECT
   
   protected:
     CryptoBackendFactory();
