@@ -55,7 +55,7 @@ class KDE_EXPORT KGanttItem : public TQObject
 //////////////////////////////////
 {
 
-  Q_OBJECT
+  TQ_OBJECT
   
 
 
