@@ -88,7 +88,7 @@ xQGanttBarViewPort::xQGanttBarViewPort(KGanttItem* toplevelitem,
 
   recalc(); adjustSize();
 
-  setFocusPolicy(TQ_StrongFocus);
+  setFocusPolicy(TQWidget::StrongFocus);
   _mode = Init;
 
 }
