@@ -22,7 +22,7 @@
 
 #include <tqobject.h>
 #include "kmaccount.h"
-#include <tdepimmacros.h>
+#include <kdemacros.h>
 
 class TQString;
 class TQStringList;
@@ -34,7 +34,7 @@ namespace KMail {
  */
 class KDE_EXPORT AccountManager: public TQObject
 {
-  Q_OBJECT
+  TQ_OBJECT
   
   friend class ::KMAccount;
 
