@@ -17,7 +17,7 @@ class KURLRequester;
 
 class KMFilterActionWithAddressWidget : public TQWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   KMFilterActionWithAddressWidget( TQWidget* parent=0, const char* name=0 );
@@ -40,7 +40,7 @@ private:
 
 class KMSoundTestWidget : public TQWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   KMSoundTestWidget( TQWidget * parent, const char * name=0 );
