@@ -10,7 +10,7 @@
 
 class KDE_EXPORT KMobileClient : public DCOPClient
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KMobileClient();
