@@ -15,7 +15,7 @@
 */
 
 #include <tdeaboutdata.h>
-#include <tdepimmacros.h>
+#include <kdemacros.h>
 
 #ifndef KNODE_ABOUTDATA_H
 #define KNODE_ABOUTDATA_H
