@@ -509,7 +509,7 @@ void KNotesApp::mousePressEvent( TQMouseEvent* e )
 void KNotesApp::slotShowNote()
 {
     // tell the WM to give this note focus
-    showNote( TQString::fromUtf8( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() ) );
+    showNote( TQString::fromUtf8( sender()->name() ) );
 }
 
 void KNotesApp::slotWalkThroughNotes()
