@@ -114,7 +114,7 @@ class KNotesIconView : public TDEIconView
 
 class KNoteEditDlg : public KDialogBase, virtual public KXMLGUIClient
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
