@@ -537,7 +537,7 @@ void KOAttendeeEditor::declineForMe()
 
 bool KOAttendeeEditor::eventFilter(TQObject *watched, TQEvent *ev)
 {
-  if ( watched && TQT_BASE_OBJECT(watched) == TQT_BASE_OBJECT(mNameEdit) && ev->type() == TQEvent::FocusIn &&
+  if ( watched && watched == mNameEdit && ev->type() == TQEvent::FocusIn &&
        currentAttendee() == 0 ) {
     addNewAttendee();
   }
