@@ -983,7 +983,7 @@ void KOEditorFreeBusy::slotOrganizerChanged(const TQString & newOrganizer)
 
 bool KOEditorFreeBusy::eventFilter( TQObject *watched, TQEvent *event )
 {
-  if ( TQT_BASE_OBJECT(watched) == TQT_BASE_OBJECT(mGanttView->timeHeaderWidget()) &&
+  if ( watched == mGanttView->timeHeaderWidget() &&
        event->type() >= TQEvent::MouseButtonPress && event->type() <= TQEvent::MouseMove ) {
     return true;
   } else {
