@@ -459,17 +459,17 @@ void MultiAgendaView::updateConfig()
 
 bool MultiAgendaView::eventFilter(TQObject * obj, TQEvent * event)
 {
-  if ( obj->className() == TQCString(TQSPLITTERHANDLE_OBJECT_NAME_STRING) ) {
+  if ( obj->className() == TQCString("TQSplitterHandle") ) {
     // KDE4: not needed anymore, TQSplitter has a moved signal there
     if ( (event->type() == TQEvent::MouseMove && TDEGlobalSettings::opaqueResize())
            || event->type() == TQEvent::MouseButtonRelease ) {
       FOREACH_VIEW( agenda ) {
-        if ( TQT_BASE_OBJECT(agenda->splitter()) == TQT_BASE_OBJECT(obj->parent()) )
+        if ( agenda->splitter() == obj->parent() )
           mLastMovedSplitter = agenda->splitter();
       }
-      if ( TQT_BASE_OBJECT(mLeftSplitter )== TQT_BASE_OBJECT(obj->parent()) )
+      if ( mLeftSplitter == obj->parent() )
         mLastMovedSplitter = mLeftSplitter;
-      else if ( TQT_BASE_OBJECT(mRightSplitter) == TQT_BASE_OBJECT(obj->parent()) )
+      else if ( mRightSplitter == obj->parent() )
         mLastMovedSplitter = mRightSplitter;
       TQTimer::singleShot( 0, this, TQT_SLOT(resizeSplitters()) );
     }
@@ -542,7 +542,7 @@ void MultiAgendaView::zoomView( const int delta, const TQPoint & pos, const Qt::
 // KDE4: not needed, use existing TQSplitter signals instead
 void MultiAgendaView::installSplitterEventFilter(TQSplitter * splitter)
 {
-  TQObjectList *objlist = splitter->queryList( TQSPLITTERHANDLE_OBJECT_NAME_STRING );
+  TQObjectList *objlist = splitter->queryList( "TQSplitterHandle" );
   // HACK: when not being visible, the splitter handle is sometimes not found
   // for unknown reasons, so trigger an update when we are shown again
   if ( objlist->count() == 0 && !isVisible() )
