@@ -26,7 +26,7 @@ class TQComboBox;
 
 class ExchangeDialog : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
   public:
     ExchangeDialog( const TQDate &start, const TQDate &end, TQWidget *parent=0);
