@@ -20,13 +20,13 @@
 
 #include <tdelistview.h>
 #include <tqptrlist.h>
-#include <tdepimmacros.h>
+#include <kdemacros.h>
 
 class KTNEFAttach;
 
 class KDE_EXPORT KTNEFView : public TDEListView
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
