@@ -34,7 +34,7 @@ namespace KPIM {
 	
 class KDE_EXPORT ExchangeAccount : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
   public:
     ExchangeAccount( const TQString &host, const TQString &port,
