@@ -22,7 +22,7 @@
 #define RESOURCEXMLRPCCONFIG_H
 
 #include <tderesources/configwidget.h>
-#include <tdepimmacros.h>
+#include <kdemacros.h>
 
 class KIntSpinBox;
 class KLineEdit;
@@ -32,7 +32,7 @@ namespace KCal {
 
 class KDE_EXPORT ResourceXMLRPCConfig : public KRES::ConfigWidget
 { 
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
