@@ -153,7 +153,7 @@ bool ResourceXMLRPC::doOpen()
   mServer->setUrl( KURL( mPrefs->url() ) );
   mServer->setUserAgent( "KDE-AddressBook" );
 
-  TQMap<TQString, TQVariant> args;
+  TQStringVariantMap args;
   args.insert( "domain", mPrefs->domain() );
   args.insert( "username", mPrefs->user() );
   args.insert( "password", mPrefs->password() );
@@ -169,7 +169,7 @@ bool ResourceXMLRPC::doOpen()
 
 void ResourceXMLRPC::doClose()
 {
-  TQMap<TQString, TQVariant> args;
+  TQStringVariantMap args;
   args.insert( "sessionid", mSessionID );
   args.insert( "kp3", mKp3 );
 
@@ -196,7 +196,7 @@ bool ResourceXMLRPC::asyncLoad()
 
   loadCache();
 
-  TQMap<TQString, TQVariant> args;
+  TQStringVariantMap args;
   args.insert( "start", "0" );
   args.insert( "query", "" );
   args.insert( "filter", "" );
@@ -208,7 +208,7 @@ bool ResourceXMLRPC::asyncLoad()
                  this, TQT_SLOT( listContactsFinished( const TQValueList<TQVariant>&, const TQVariant& ) ),
                  this, TQT_SLOT( fault( int, const TQString&, const TQVariant& ) ) );
 
-  mServer->call( LoadCategoriesCommand, TQVariant( false, 0 ),
+  mServer->call( LoadCategoriesCommand, TQVariant( false ),
                  this, TQT_SLOT( loadCategoriesFinished( const TQValueList<TQVariant>&, const TQVariant& ) ),
                  this, TQT_SLOT( fault( int, const TQString&, const TQVariant& ) ) );
 
@@ -249,7 +249,7 @@ bool ResourceXMLRPC::asyncSave( Ticket* )
 
 void ResourceXMLRPC::addContact( const Addressee& addr )
 {
-  TQMap<TQString, TQVariant> args;
+  TQStringVariantMap args;
   writeContact( addr, args );
 
   mServer->call( AddContactCommand, args,
@@ -265,7 +265,7 @@ void ResourceXMLRPC::updateContact( const Addressee& addr )
     return;
   }
 
-  TQMap<TQString, TQVariant> args;
+  TQStringVariantMap args;
   writeContact( addr, args );
 
   args.insert( "id", idMapper().remoteId( addr.uid() ) );
@@ -292,7 +292,7 @@ void ResourceXMLRPC::deleteContact( const Addressee& addr )
 void ResourceXMLRPC::loginFinished( const TQValueList<TQVariant> &variant,
                                     const TQVariant& )
 {
-  TQMap<TQString, TQVariant> map = variant[0].toMap();
+  TQStringVariantMap map = variant[0].toMap();
 
   KURL url( mPrefs->url() );
   if ( map[ "GOAWAY" ].toString() == "XOXO" ) { // failed
@@ -313,7 +313,7 @@ void ResourceXMLRPC::loginFinished( const TQValueList<TQVariant> &variant,
 void ResourceXMLRPC::logoutFinished( const TQValueList<TQVariant> &variant,
                                      const TQVariant& )
 {
-  TQMap<TQString, TQVariant> map = variant[0].toMap();
+  TQStringVariantMap map = variant[0].toMap();
 
   if ( map[ "GOODBYE" ].toString() != "XOXO" )
     addressBook()->error( i18n( "Logout failed, please check your username and password." ) );
@@ -335,7 +335,7 @@ void ResourceXMLRPC::listContactsFinished( const TQValueList<TQVariant> &mapList
 
   TDEABC::Addressee::List serverContacts;
   for ( contactIt = contactList.begin(); contactIt != contactList.end(); ++contactIt ) {
-    const TQMap<TQString, TQVariant> map = (*contactIt).toMap();
+    const TQStringVariantMap map = (*contactIt).toMap();
 
     Addressee addr;
     TQString uid;
@@ -451,7 +451,7 @@ TQString ResourceXMLRPC::addrTypesToTypeStr( int typeMask )
   return types.join( ";" );
 }
 
-void ResourceXMLRPC::writeContact( const Addressee &addr, TQMap<TQString, TQVariant> &args )
+void ResourceXMLRPC::writeContact( const Addressee &addr, TQStringVariantMap &args )
 {
   args.insert( "access", ( addr.secrecy().type() == Secrecy::Private ? "private" : "public" ) );
   args.insert( "fn", addr.formattedName() );
@@ -476,7 +476,7 @@ void ResourceXMLRPC::writeContact( const Addressee &addr, TQMap<TQString, TQVari
   TQStringList::ConstIterator catIt;
   const TQStringList categories = addr.categories();
 
-  TQMap<TQString, TQVariant> catMap;
+  TQStringVariantMap catMap;
   int counter = 0;
   for ( catIt = categories.begin(); catIt != categories.end(); ++catIt ) {
     TQMap<TQString, int>::ConstIterator it = mCategoryMap.find( *catIt );
@@ -593,11 +593,11 @@ void ResourceXMLRPC::writeContact( const Addressee &addr, TQMap<TQString, TQVari
     args.insert( "freebusy_url", url );
 }
 
-void ResourceXMLRPC::readContact( const TQMap<TQString, TQVariant> &args, Addressee &addr, TQString &uid )
+void ResourceXMLRPC::readContact( const TQStringVariantMap &args, Addressee &addr, TQString &uid )
 {
   Address addrOne, addrTwo;
 
-  TQMap<TQString, TQVariant>::ConstIterator it;
+  TQStringVariantMap::ConstIterator it;
   for ( it = args.begin(); it != args.end(); ++it ) {
     if ( it.key() == "id" ) {
       uid = it.data().toString();
@@ -710,8 +710,8 @@ void ResourceXMLRPC::readContact( const TQMap<TQString, TQVariant> &args, Addres
       addr.insertEmail( it.data().toString(), false );
     } else if ( it.key() == "email_home_type" ) {
     } else if ( it.key() == "cat_id" ) {
-      const TQMap<TQString, TQVariant> categories = it.data().toMap();
-      TQMap<TQString, TQVariant>::ConstIterator it;
+      const TQStringVariantMap categories = it.data().toMap();
+      TQStringVariantMap::ConstIterator it;
 
       for ( it = categories.begin(); it != categories.end(); ++it )
         addr.insertCategory( it.data().toString() );
@@ -744,8 +744,8 @@ void ResourceXMLRPC::loadCategoriesFinished( const TQValueList<TQVariant> &mapLi
 {
   mCategoryMap.clear();
 
-  const TQMap<TQString, TQVariant> map = mapList[ 0 ].toMap();
-  TQMap<TQString, TQVariant>::ConstIterator it;
+  const TQStringVariantMap map = mapList[ 0 ].toMap();
+  TQStringVariantMap::ConstIterator it;
 
   KABPrefs *prefs = KABPrefs::instance();
   for ( it = map.begin(); it != map.end(); ++it ) {
@@ -764,8 +764,8 @@ void ResourceXMLRPC::loadCustomFieldsFinished( const TQValueList<TQVariant> &map
 {
   mCustomFieldsMap.clear();
 
-  const TQMap<TQString, TQVariant> map = mapList[ 0 ].toMap();
-  TQMap<TQString, TQVariant>::ConstIterator it;
+  const TQStringVariantMap map = mapList[ 0 ].toMap();
+  TQStringVariantMap::ConstIterator it;
 
   for ( it = map.begin(); it != map.end(); ++it )
     mCustomFieldsMap.insert( it.key(), it.data().toString() );
