@@ -33,7 +33,7 @@ namespace KCal {
 
 class KDE_EXPORT ResourceFeaturePlanConfig : public KRES::ConfigWidget
 { 
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
