@@ -23,13 +23,13 @@
 #define TDEABC_RESOURCEGROUPDAV_H
 
 #include "tdeabc_resourcegroupwarebase.h"
-#include <tdepimmacros.h>
+#include <kdemacros.h>
 
 namespace TDEABC {
 
 class KDE_EXPORT ResourceGroupDav : public ResourceGroupwareBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
