@@ -51,7 +51,7 @@ class KDE_EXPORT ResourceKolab : public KCal::ResourceCalendar,
                       public KCal::IncidenceBase::Observer,
                       public Kolab::ResourceKolabBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
     friend struct TemporarySilencer;
 
