@@ -52,7 +52,7 @@ class KDE_EXPORT ResourceScalix : public ResourceNotes,
                       public KCal::IncidenceBase::Observer,
                       public ResourceScalixBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
