@@ -30,7 +30,7 @@ class TQGroupBox;
 
 class KDE_EXPORT GroupwiseWizard : public TDEConfigWizard
 {
-    Q_OBJECT
+    TQ_OBJECT
   
   public:
     GroupwiseWizard();
